@@ -2,13 +2,13 @@ from typing import Optional
 
 from PySide6.QtWidgets import QDialog, QWidget
 
-from foundry.game.gfx.Palette import PaletteProtocol
+from foundry.core.palette.Palette import MutablePaletteProtocol
 from foundry.gui.ColorSelector import ColorSelector
 from foundry.gui.PaletteWidget import PaletteWidget
 
 
 class PaletteEditorWidget(PaletteWidget):
-    def __init__(self, parent: Optional[QWidget], palette: PaletteProtocol):
+    def __init__(self, parent: Optional[QWidget], palette: MutablePaletteProtocol):
         super().__init__(parent, palette)
 
         for idx, btn in enumerate(self._buttons):
