@@ -3,7 +3,7 @@ from typing import Optional
 from PySide6.QtCore import Signal, SignalInstance
 from PySide6.QtWidgets import QHBoxLayout, QWidget
 
-from foundry.game.gfx.Palette import PaletteProtocol
+from foundry.core.palette.Palette import MutablePaletteProtocol
 from foundry.gui.ColorButtonWidget import ColorButtonWidget
 
 
@@ -13,13 +13,13 @@ class PaletteWidget(QWidget):
 
     Attributes
     ----------
-    palette_changed: Signal[Palette]
+    palette_changed: Signal[palette]
         Slot associated with the palette viewer changing its palette.
     """
 
-    palette_changed: SignalInstance = Signal(PaletteProtocol)  # type: ignore
+    palette_changed: SignalInstance = Signal(MutablePaletteProtocol)  # type: ignore
 
-    def __init__(self, parent: Optional[QWidget], palette: PaletteProtocol):
+    def __init__(self, parent: Optional[QWidget], palette: MutablePaletteProtocol):
         super().__init__(parent)
         self._palette = palette
 
@@ -35,11 +35,11 @@ class PaletteWidget(QWidget):
         return f"{self.__class__.__name__}({self.parent}, {self.palette})"
 
     @property
-    def palette(self) -> PaletteProtocol:
+    def palette(self) -> MutablePaletteProtocol:
         return self._palette
 
     @palette.setter
-    def palette(self, palette: PaletteProtocol):
+    def palette(self, palette: MutablePaletteProtocol):
         self._palette = palette
         self.palette_changed.emit(palette)
         self._update()
